
// (c) COPYRIGHT URI/MIT 1996,2000
// Please read the full copyright statement in the file COPYRIGHT.
//
// Authors:
//      jhrg,jimg       James Gallagher (jgallagher@gso.uri.edu)

// Implementation for ClientList. See ClientByte.cc
//
// jhrg 1/12/95

#ifdef __GNUG__
#pragma implementation
#endif

#include "config_writeval.h"

#include <assert.h>
#include <iostream>

#include <Pix.h>
#include <string>

#include "InternalErr.h"
#include "ClientList.h"
#include "name_map.h"

extern name_map names;
extern bool translate;

extern void smart_newline(ostream &os, Type type);

List *
NewList(const string &n, BaseType *v)
{
    return new ClientList(n, v);
}

BaseType *
ClientList::ptr_duplicate()
{
    return new ClientList(*this);
}

ClientList::ClientList(const string &n, BaseType *v) : List(n, v)
{
    set_matlab_name(n);
}

ClientList::~ClientList()
{
}

bool 
ClientList::read(const string &)
{
  throw InternalErr(__FILE__, __LINE__, "Called unimplemented read method");
}

void 
ClientList::print_val(ostream &os, string, bool print_decl_p)
{
    if (print_decl_p) {
	os << type_name() << endl << var()->type_name() << " " 
	   << get_matlab_name() << " " << length() << endl;
    }

    for (int i = 0; i < length(); ++i)
	var(i)->print_val(os, "", false);
}

AttrTable &
ClientList::getAttrTable()
{
    return _attr;
}

void 
ClientList::setAttrTable(AttrTable &attr)
{
    _attr = attr;
}
void
ClientList::set_name(const string &n)
{
    BaseType::set_name(n);
    set_matlab_name(n);
}

string 
ClientList::get_matlab_name() const
{
    return _matlabName; 
}

void 
ClientList::set_matlab_name(const string &name)
{ 
    _matlabName = names.lookup(name, translate);
}

// $Log: ClientList.cc,v $
// Revision 1.16.2.2  2002/09/05 22:26:49  pwest
// Removed includes to SLList and DLList. These are not necessary and no longer
// supported.
//
// Revision 1.16.2.1  2001/08/21 16:47:54  dan
// Added set/accessor methods for a new local member, matlab_name
// which stores the translated name of the variable so that it does
// not have to be translated during serialization.  This optimizes
// the amount of time spent in variable name translation to a single
// instance.
//
// Added a local method, set_name() which works with the BaseType
// pointer to update both the BaseType name member and local matlab_name
// member.
//
// Revision 1.16  2000/10/03 22:24:17  jimg
// Reorganized the CVS Log entries.
// Changed the read() mfunc definitions to match the 3.2 dap++ library.
//
// Revision 1.15  2000/07/21 10:21:56  rmorris
// Merged with win32-mlclient-branch.
//
// Revision 1.14.2.2  2000/07/09 22:26:32  rmorris
// Mod's to increase portability, minimize ifdef's for win32.
//
// Revision 1.14.2.1  2000/06/26 22:54:26  rmorris
// Mods for port to win32.
//
// Revision 1.14  2000/06/07 00:28:31  jimg
// Merged changes from version 3.1.4
//
// Revision 1.13.12.1  2000/06/02 23:03:32  jimg
// Fixes for AttrTables with no entries.
// Added support for name translation and a DODS_ML_Real_Name attribute.
// Changed the `size' attribtue's name to DODS_ML_Size.
//
// Revision 1.13  1999/03/24 06:23:42  brent
// convert String.h to std lib <string>, convert to packages regex -- B^2
//
// Revision 1.12  1998/11/19 20:53:33  jimg
// Fixed the extra newline bug.
//
// Revision 1.11  1998/09/16 23:02:21  jimg
// Removed write_val() and replaced it with print_val() and print_all_vals()
//
// Revision 1.10  1998/08/03 16:39:49  jimg
// Fixed write_val mfunc so that outermost is no longer used
//
// Revision 1.9  1997/10/04 00:40:04  jimg
// Added changes to support the new deserialize() mfunc and write_val().
//
// Revision 1.8  1997/04/19 00:54:55  jimg
// Changed ouput stream to simplify reading (for loaddods).
//
// Revision 1.7  1997/02/06 20:43:38  jimg
// Fixed log messages
//
// Revision 1.6  1997/01/10 06:49:34  jimg
// Changed call to name_map::lookup() so that non-alphanumerics are mapped to
// underscore. 
//
// Revision 1.5  1996/11/23 05:12:10  jimg
// Added support for variable renaming via the name_map object.
//
// Revision 1.4  1996/10/25 23:11:33  jimg
// Changed/Fixed write_val() so that it uses smart_newline().
//
// Revision 1.3  1996/10/23 23:46:42  jimg
// Modified so that writeval outputs a `recursive' data stream. Thus any
// data type can be written and later read without being flattened. This
// change was made so that the NSCAT data which is represented as a Sequence
// of Structures.
//
// Revision 1.2  1996/10/07 21:00:26  jimg
// Fixed Headers.
//
// Revision 1.1  1996/09/30 23:59:12  jimg
// Added.
